==> ksubtitleripper_0.2.orig.tar.gz: ksubtitleripper-0.2/src/extractprocess.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Sergio Cambra Garca                            *
 *   runico@users.berlios.de                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef EXTRACTPROCESS_H
#define EXTRACTPROCESS_H

#include <kprocio.h>

class Project;
class QWidget;

/**
@author Sergio Cambra
*/

class ExtractProcess : public KProcIO {
public:
    ExtractProcess( const Project *prj, QWidget *parent = 0, QTextCodec *codec = 0 );
    ~ExtractProcess();

private:
	bool download( const KURL::List& urls );
	
	QWidget *widget;
};

#endif

==> ksubtitleripper_0.3.1.orig.tar.gz: ksubtitleripper-0.3.1/src/extractprocess.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Sergio Cambra Garca                            *
 *   runico@users.berlios.de                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef EXTRACTPROCESS_H
#define EXTRACTPROCESS_H

#include <kprocio.h>

class Project;

/**
@author Sergio Cambra
*/

class ExtractProcess : public KProcIO {
public:
    ExtractProcess( Project *prj, bool& success, QTextCodec *codec = 0 );
	~ExtractProcess() {}
};

#endif
